# GatorHoldEm

Github repo: https://github.com/y0sh12/GatorHoldEm

Installation: 
1. Use `pip install GatorHoldEm` to install the library
2. Run the command `gatorholdem` to run the client*.

    *If using WSL, you will need an X server to support graphical display

After joining a room and having at least 2 clients in the same room, click the "Start the Game!" button from one of the clients. 
Then click the 'I am ready' button for the game GUI to show.
Enjoy the game!
Avoid using the same room name twice for now.

Members of the group:

-Yaswanth Potluri

-Azharullah Baig

-Sean O'Reilly

-Bharat Samineni

-Adriel Muhammed


